@@ -8,84 +8,88 @@ our %VALUES;
     no strict 'vars';
     %VALUES = %{
 $VAR1 = {
-          'version' => '2.008012',
+          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
+          'c_flags' => '-pthread ',
+          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
+          'linker' => 'c++ -shared -fPIC  ',
+          'prefix' => '/usr/local',
           '_libraries' => {
-                            'gl' => {
-                                      'link' => '-lwx_gtk2_gl',
-                                      'dll' => 'libwx_gtk2_gl.so.3.0'
-                                    },
-                            'fl' => {
-                                      'link' => '-lwx_gtk2_fl',
-                                      'dll' => 'libwx_gtk2_fl.so.3.0'
-                                    },
-                            'base' => {
-                                        'dll' => 'libwx_base.so.3.0',
-                                        'link' => '-lwx_base'
+                            'html' => {
+                                        'dll' => 'libwx_gtk2_html.so.3.0',
+                                        'link' => '-lwx_gtk2_html'
                                       },
+                            'adv' => {
+                                       'link' => '-lwx_gtk2_adv',
+                                       'dll' => 'libwx_gtk2_adv.so.3.0'
+                                     },
                             'core' => {
                                         'link' => '-lwx_gtk2_core',
                                         'dll' => 'libwx_gtk2_core.so.3.0'
                                       },
-                            'adv' => {
-                                       'dll' => 'libwx_gtk2_adv.so.3.0',
-                                       'link' => '-lwx_gtk2_adv'
-                                     },
-                            'html' => {
-                                        'link' => '-lwx_gtk2_html',
-                                        'dll' => 'libwx_gtk2_html.so.3.0'
-                                      },
-                            'net' => {
-                                       'dll' => 'libwx_base_net.so.3.0',
-                                       'link' => '-lwx_base_net'
-                                     },
-                            'qa' => {
-                                      'dll' => 'libwx_gtk2_qa.so.3.0',
-                                      'link' => '-lwx_gtk2_qa'
-                                    },
                             'xrc' => {
                                        'link' => '-lwx_gtk2_xrc',
                                        'dll' => 'libwx_gtk2_xrc.so.3.0'
                                      },
-                            'xml' => {
-                                       'link' => '-lwx_base_xml',
-                                       'dll' => 'libwx_base_xml.so.3.0'
+                            'stc' => {
+                                       'link' => '-lwx_gtk2_stc',
+                                       'dll' => 'libwx_gtk2_stc.so.3.0'
+                                     },
+                            'aui' => {
+                                       'dll' => 'libwx_gtk2_aui.so.3.0',
+                                       'link' => '-lwx_gtk2_aui'
                                      },
-                            'gizmos' => {
-                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
-                                          'link' => '-lwx_gtk2_gizmos'
-                                        },
                             'richtext' => {
                                             'dll' => 'libwx_gtk2_richtext.so.3.0',
                                             'link' => '-lwx_gtk2_richtext'
                                           },
-                            'aui' => {
-                                       'link' => '-lwx_gtk2_aui',
-                                       'dll' => 'libwx_gtk2_aui.so.3.0'
+                            'gl' => {
+                                      'link' => '-lwx_gtk2_gl',
+                                      'dll' => 'libwx_gtk2_gl.so.3.0'
+                                    },
+                            'media' => {
+                                         'link' => '-lwx_gtk2_media',
+                                         'dll' => 'libwx_gtk2_media.so.3.0'
+                                       },
+                            'base' => {
+                                        'link' => '-lwx_base',
+                                        'dll' => 'libwx_base.so.3.0'
+                                      },
+                            'gizmos' => {
+                                          'link' => '-lwx_gtk2_gizmos',
+                                          'dll' => 'libwx_gtk2_gizmos.so.3.0'
+                                        },
+                            'net' => {
+                                       'link' => '-lwx_base_net',
+                                       'dll' => 'libwx_base_net.so.3.0'
                                      },
-                            'stc' => {
-                                       'link' => '-lwx_gtk2_stc',
-                                       'dll' => 'libwx_gtk2_stc.so.3.0'
-                                     }
+                            'fl' => {
+                                      'dll' => 'libwx_gtk2_fl.so.3.0',
+                                      'link' => '-lwx_gtk2_fl'
+                                    },
+                            'xml' => {
+                                       'dll' => 'libwx_base_xml.so.3.0',
+                                       'link' => '-lwx_base_xml'
+                                     },
+                            'qa' => {
+                                      'link' => '-lwx_gtk2_qa',
+                                      'dll' => 'libwx_gtk2_qa.so.3.0'
+                                    }
                           },
-          'alien_base' => 'gtk2_gcc',
-          'link_flags' => '',
-          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
-          'c_flags' => '-pthread ',
-          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
-          'linker' => 'c++ -shared -fPIC  ',
-          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
-          'prefix' => '/usr/local',
-          'compiler' => 'c++',
+          'version' => '2.008012',
           'config' => {
-                        'mslu' => 0,
-                        'unicode' => 0,
-                        'compiler_version' => '3.4',
-                        'compiler_kind' => 'gcc',
                         'toolkit' => 'gtk2',
+                        'compiler_kind' => 'gcc',
+                        'compiler_version' => '3.4',
                         'debug' => 0,
-                        'build' => 'multi'
+                        'mslu' => 0,
+                        'build' => 'multi',
+                        'unicode' => 0
                       },
-          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc'
+          'alien_base' => 'gtk2_gcc',
+          'compiler' => 'c++',
+          'link_flags' => '',
+          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include ',
+          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ '
         };
     };
 }
