@@ -8,48 +8,36 @@ our %VALUES;
     no strict 'vars';
     %VALUES = %{
 $VAR1 = {
-          'version' => '2.008012',
-          'link_flags' => '',
-          'config' => {
-                        'build' => 'multi',
-                        'debug' => 0,
-                        'unicode' => 0,
-                        'toolkit' => 'gtk2',
-                        'compiler_version' => '3.4',
-                        'compiler_kind' => 'gcc',
-                        'mslu' => 0
-                      },
-          'alien_base' => 'gtk2_gcc',
-          'compiler' => 'c++',
-          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
-          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
-          'c_flags' => '-pthread ',
-          'linker' => 'c++ -shared -fPIC  ',
+          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
           '_libraries' => {
                             'base' => {
                                         'dll' => 'libwx_base.so.3.0',
                                         'link' => '-lwx_base'
                                       },
+                            'xml' => {
+                                       'dll' => 'libwx_base_xml.so.3.0',
+                                       'link' => '-lwx_base_xml'
+                                     },
+                            'qa' => {
+                                      'link' => '-lwx_gtk2_qa',
+                                      'dll' => 'libwx_gtk2_qa.so.3.0'
+                                    },
                             'core' => {
-                                        'dll' => 'libwx_gtk2_core.so.3.0',
-                                        'link' => '-lwx_gtk2_core'
+                                        'link' => '-lwx_gtk2_core',
+                                        'dll' => 'libwx_gtk2_core.so.3.0'
                                       },
                             'xrc' => {
-                                       'dll' => 'libwx_gtk2_xrc.so.3.0',
-                                       'link' => '-lwx_gtk2_xrc'
+                                       'link' => '-lwx_gtk2_xrc',
+                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                      },
                             'html' => {
-                                        'dll' => 'libwx_gtk2_html.so.3.0',
-                                        'link' => '-lwx_gtk2_html'
+                                        'link' => '-lwx_gtk2_html',
+                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                       },
                             'richtext' => {
                                             'dll' => 'libwx_gtk2_richtext.so.3.0',
                                             'link' => '-lwx_gtk2_richtext'
                                           },
-                            'qa' => {
-                                      'dll' => 'libwx_gtk2_qa.so.3.0',
-                                      'link' => '-lwx_gtk2_qa'
-                                    },
                             'stc' => {
                                        'link' => '-lwx_gtk2_stc',
                                        'dll' => 'libwx_gtk2_stc.so.3.0'
@@ -58,34 +46,50 @@ $VAR1 = {
                                        'dll' => 'libwx_gtk2_adv.so.3.0',
                                        'link' => '-lwx_gtk2_adv'
                                      },
-                            'gl' => {
-                                      'link' => '-lwx_gtk2_gl',
-                                      'dll' => 'libwx_gtk2_gl.so.3.0'
-                                    },
-                            'xml' => {
-                                       'link' => '-lwx_base_xml',
-                                       'dll' => 'libwx_base_xml.so.3.0'
-                                     },
-                            'fl' => {
-                                      'dll' => 'libwx_gtk2_fl.so.3.0',
-                                      'link' => '-lwx_gtk2_fl'
-                                    },
                             'net' => {
-                                       'dll' => 'libwx_base_net.so.3.0',
-                                       'link' => '-lwx_base_net'
-                                     },
-                            'aui' => {
-                                       'dll' => 'libwx_gtk2_aui.so.3.0',
-                                       'link' => '-lwx_gtk2_aui'
+                                       'link' => '-lwx_base_net',
+                                       'dll' => 'libwx_base_net.so.3.0'
                                      },
                             'gizmos' => {
-                                          'link' => '-lwx_gtk2_gizmos',
-                                          'dll' => 'libwx_gtk2_gizmos.so.3.0'
-                                        }
+                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
+                                          'link' => '-lwx_gtk2_gizmos'
+                                        },
+                            'fl' => {
+                                      'link' => '-lwx_gtk2_fl',
+                                      'dll' => 'libwx_gtk2_fl.so.3.0'
+                                    },
+                            'gl' => {
+                                      'dll' => 'libwx_gtk2_gl.so.3.0',
+                                      'link' => '-lwx_gtk2_gl'
+                                    },
+                            'aui' => {
+                                       'link' => '-lwx_gtk2_aui',
+                                       'dll' => 'libwx_gtk2_aui.so.3.0'
+                                     },
+                            'media' => {
+                                         'dll' => 'libwx_gtk2_media.so.3.0',
+                                         'link' => '-lwx_gtk2_media'
+                                       }
                           },
+          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
           'prefix' => '/usr/local',
+          'link_flags' => '',
+          'version' => '2.008012',
+          'linker' => 'c++ -shared -fPIC  ',
+          'alien_base' => 'gtk2_gcc',
           'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
-          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib'
+          'c_flags' => '-pthread ',
+          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include -I/usr/X11R6/include ',
+          'compiler' => 'c++',
+          'config' => {
+                        'compiler_kind' => 'gcc',
+                        'compiler_version' => '3.4',
+                        'debug' => 0,
+                        'toolkit' => 'gtk2',
+                        'mslu' => 0,
+                        'build' => 'multi',
+                        'unicode' => 0
+                      }
         };
     };
 }
